mysql.exceptions.server.Warn_Field_Resolved

Package mysql :: Package exceptions :: Module server :: Class Warn_Field_Resolved |
[hide private]
[frames] | no frames]

# Class Warn_Field_Resolved

source code

    exceptions.Exception --+
                           |
                  base.Error --+
                               |
                base.MySQL_Error --+
                                   |
                                  Warn_Field_Resolved

Field or reference '%s%s%s%s%s' of SELECT #%d was resolved in SELECT #%d

Instance Methods | [hide private]
Inherited from `base.MySQL_Error`: `__init__`, `__repr__`, `__str__` Inherited from `exceptions.Exception`: `__getitem__`

Instance Variables | [hide private]
Inherited from `base.MySQL_Error`: `errno`, `error_string`